@@ -12,7 +12,7 @@ from django.contrib.auth import get_user_model
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models import Exists, OuterRef
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from lms.djangoapps.grades import api as grades_api
 from opaque_keys.edx.keys import CourseKey, UsageKey
 from openedx.core.djangoapps.course_groups.cohorts import get_cohort
@@ -312,7 +312,7 @@ class GradeCSVProcessor(DeferrableMixin, GradedSubsectionMixin, CSVProcessor):
         )
         self.append_columns(
             self._subsection_column_names(
-                self._subsections.keys(),  # pylint: disable=dict-keys-not-iterating, useless-suppression
+                self._subsections.keys(),  # pylint: disable=useless-suppression
                 self.subsection_prefixes
             )
         )
@@ -549,7 +549,7 @@ class InterventionCSVProcessor(GradedSubsectionMixin, CSVProcessor):
         )
         self.append_columns(
             self._subsection_column_names(
-                self._subsections.keys(),  # pylint: disable=dict-keys-not-iterating, useless-suppression
+                self._subsections.keys(),  # pylint: disable=useless-suppression
                 self.subsection_prefixes
             )
         )
